@@ -30,9 +30,6 @@ typedef void (*EntryDirectoryChangedFunc) (EntryDirectory *ed,
 
 EntryDirectory *entry_directory_new        (DesktopEntryType  entry_type,
                                             const char       *path);
-EntryDirectory *entry_directory_new_legacy (DesktopEntryType  entry_type,
-                                            const char       *path,
-                                            const char       *legacy_prefix);
 
 EntryDirectory *entry_directory_ref   (EntryDirectory *ed);
 void            entry_directory_unref (EntryDirectory *ed);
